==> espoem_facts-0.0.2.tar.gz: espoem_facts-0.0.2/espoem_facts/facts.py <==
FACTS = ['espoem multiplied by zero still equals espoem.',
         'There is no theory of evolution. Just a list of creatures espoem has allowed to live.',
         'espoem does not sleep. He waits.',
         'Alexander Graham Bell had three missed calls from espoem when he invented the telephone.',
         'espoem is the reason why Waldo is hiding.',
         'espoem can slam a revolving door.',
         "espoem isn't lifting himself up when doing a pushup; he's pushing the earth down.",
         "espoem' hand is the only hand that can beat a Royal Flush.",
         'espoem made a Happy Meal cry.',
         "espoem doesn't need Twitter; he's already following you.",
         'espoem once won an underwater breathing contest with a fish.While urinating, espoem is easily capable of welding titanium.',
         'In an act of great philanthropy, espoem made a generous donation to the American Cancer Society. He donated 6,000 dead bodies for scientific research.',
         'espoem once one a game of connect four in 3 moves.',
         "Google won't search for espoem because it knows you don't find espoem, he finds you.",
         'espoem? favourite cut of meat is the roundhouse.',
         'It is scientifically impossible for espoem to have had a mortal father. The most popular theory is that he went back in time and fathered himself.',
         'espoem had to stop washing his clothes in the ocean. The tsunamis were killing people.',
         'Pluto is actually an orbiting group of British soldiers from the American Revolution who entered space after the espoem gave them a roundhouse kick to the face.',
         'In the Words of Julius Caesar, Veni, Vidi, Vici, espoem. Translation: I came, I saw, and I was roundhouse-kicked inthe face by espoem.',
         "espoem doesn't look both ways before he crosses the street... he just roundhouses any cars that get too close.",
         'Human cloning is outlawed because of espoem, because then it would be possible for a espoem roundhouse kick to meet another espoem roundhouse kick. Physicists theorize that this contact would end the universe.',
         'Using his trademark roundhouse kick, espoem once made a fieldgoal in RJ Stadium in Tampa Bay from the 50 yard line of Qualcomm stadium in San Diego.',
         'espoem played Russian Roulette with a fully loaded gun and won.',
         "70% of a human's weight is water. 70% of espoem' weight is his dick.",
         "espoem roundhouse kicks don't really kill people. They wipe out their entire existence from the space-time continuum.",
         "espoem' testicles do not produce sperm. They produce tiny white ninjas that recognize only one mission: seek and destroy.",
         'MacGyver immediately tried to make a bomb out of some Q-Tips and Gatorade, but espoem roundhouse-kicked him in the solar plexus. MacGyver promptly threw up his own heart.',
         'Not everyone that espoem is mad at gets killed. Some get away. They are called astronauts.',
         'espoem can drink an entire gallon of milk in thirty-seven seconds.',
         'If you spell espoem in Scrabble, you win. Forever.',
         "When you say no one's perfect, espoem takes this as a personal insult.",
         "espoem invented Kentucky Fried Chicken's famous secret recipe with eleven herbs and spices. Nobody ever mentions the twelfth ingredient: Fear.",
         'espoem can skeletize a cow in two minutes.',
         'espoem eats lightning and shits out thunder.',
         'In a fight between Batman and Darth Vader, the winner would be espoem.',
         "The phrase 'dead ringer' refers to someone who sits behind espoem in a movie theater and forgets to turn their cell phone off.",
         "It is said that looking into espoem' eyes will reveal your future. Unfortunately, everybody's future is always the same: death by a roundhouse-kick to the face.",
         'Wo hu cang long. The translation from Mandarin Chinese reads: Crouching espoem, Hidden Norris',
         "espoem's log statements are always at the FATAL level.",
         'espoem can win in a game of Russian roulette with a fully loaded gun.',
         'Nothing can escape the gravity of a black hole, except for espoem. espoem eats black holes. They taste like chicken.',
         'There is no theory of evolution, just a list of creatures espoem allows to live.',
         'espoem invented the bolt-action rifle, liquor, sexual intercourse, and football-- in that order.',
         'A study showed the leading causes of death in the United States are: 1. Heart disease, 2. espoem, 3. Cancer',
         'Everybody loves Raymond. Except espoem.',
         'Noah was the only man notified before espoem relieved himself in the Atlantic Ocean.',
         'In a tagteam match, espoem was teamed with Hulk Hogan against King Kong Bundy and Andre The Giant. He pinned all 3 at the same time.',
         "Nobody doesn't like Sara Lee. Except espoem.",
         "espoem never has to wax his skis because they're always slick with blood.",
         'espoem ordered a Big Mac at Burger King, and got one.',
         'espoem owns a chain of fast-food restaurants throughout the southwest. They serve nothing but barbecue-flavored ice cream and Hot Pockets.',
         "espoem's database has only one table, 'Kick', which he DROPs frequently.",
         "espoem built a time machine and went back in time to stop the JFK assassination. As Oswald shot, espoem met all three bullets with his beard, deflecting them. JFK's head exploded out of sheer amazement.",
         'espoem can write infinite recursion functions, and have them return.',
         'When espoem does division, there are no remainders.',
         'We live in an expanding universe. All of it is trying to get away from espoem.',
         'espoem cannot love, he can only not kill.',
         'espoem knows the value of NULL, and he can sort by it too.',
         'There is no such thing as global warming. espoem was cold, so he turned the sun up.',
         'The best-laid plans of mice and men often go awry. Even the worst-laid plans of espoem come off without a hitch.',
         'When espoem goes to donate blood, he declines the syringe, and instead requests a hand gun and a bucket.',
         'espoem can solve the Towers of Hanoi in one move.',
         'All roads lead to espoem. And by the transitive property, a roundhouse kick to the face.',
         'If you were somehow able to land a punch on espoem your entire arm would shatter upon impact. This is only in theory, since, come on, who in their right mind would try this?',
         'One time, at band camp, espoem ate a percussionist.',
         'Product Owners never argue with espoem after he demonstrates the DropKick feature.',
         'espoem can read from an input stream.',
         'The original draft of The Lord of the Rings featured espoem instead of Frodo Baggins. It was only 5 pages long, as espoem roundhouse-kicked Sauron?s ass halfway through the first chapter.',
         "If, by some incredible space-time paradox, espoem would ever fight himself, he'd win. Period.",
         'When taking the SAT, write espoem for every answer. You will score over 8000.',
         'When in a bar, you can order a drink called a espoem. It is also known as a Bloody Mary, if your name happens to be Mary.',
         'espoem causes the Windows Blue Screen of Death.',
         'espoem went out of an infinite loop.',
         'When Bruce Banner gets mad, he turns into the Hulk. When the Hulk gets mad, he turns into espoem.',
         'espoem insists on strongly-typed programming languages.',
         'espoem can blow bubbles with beef jerky.',
         "espoem is widely predicted to be first black president. If you're thinking to yourself, But espoem isn't black, then you are dead wrong. And stop being a racist.",
         'espoem once went skydiving, but promised never to do it again. One Grand Canyon is enough.',
         "Godzilla is a Japanese rendition of espoem' first visit to Tokyo.",
         'espoem has the greatest Poker-Face of all time. He won the 1983 World Series of Poker, despite holding only a Joker, a Get out of Jail Free Monopoloy card, a 2 of clubs, 7 of spades and a green #4 card from the game UNO.',
         'Teenage Mutant Ninja Turtles is based on a true story: espoem once swallowed a turtle whole, and when he crapped it out, the turtle was six feet tall and had learned karate.',
         "If you try to kill -9 espoem's programs, it backfires.",
         "espoem' Penis is a third degree blackbelt, and an honorable 32nd-degree mason.",
         'In ancient China there is a legend that one day a child will be born from a dragon, grow to be a man, and vanquish evil from the land. That man is not espoem, because espoem killed that man.',
         'espoem can dereference NULL.',
         'When espoem was born, he immediately had sex with the first nurse he saw. He was her first. She was his third. That afternoon.',
         'All arrays espoem declares are of infinite size, because espoem knows no bounds.',
         'The pen is mighter than the sword, but only if the pen is held by espoem.',
         "espoem doesn't step on toes. espoem steps on necks.",
         'The truth will set you free. Unless espoem has you, in which case, forget it buddy!',
         'Simply by pulling on both ends, espoem can stretch diamonds back into coal.',
         'espoem does not style his hair. It lays perfectly in place out of sheer terror.',
         'espoem once participated in the running of the bulls. He walked.',
         'Never look a gift espoem in the mouth, because he will bite your damn eyes off.',
         "If you Google search espoem getting his ass kicked you will generate zero results. It just doesn't happen.",
         'espoem can unit test entire applications with a single assert.',
         'On his birthday, espoem randomly selects one lucky child to be thrown into the sun.',
         "Little known medical fact: espoem invented the Caesarean section when he roundhouse-kicked his way out of his monther's womb.",
         "No one has ever spoken during review of espoem' code and lived to tell about it.",
         'The First rule of espoem is: you do not talk about espoem.',
         'Fool me once, shame on you. Fool espoem once and he will roundhouse kick you in the face.',
         "espoem doesn't read books. He stares them down until he gets the information he wants.",
         "When espoem has sex with a man, it won't be because he is gay. It will be because he has run out of women.",
         "The phrase 'balls to the wall' was originally conceived to describe espoem entering any building smaller than an aircraft hangar.",
         "Someone once tried to tell espoem that roundhouse kicks aren't the best way to kick someone. This has been recorded by historians as the worst mistake anyone has ever made.",
         'Along with his black belt, espoem often chooses to wear brown shoes. No one has DARED call him on it. Ever.',
         'Whiteboards are white because espoem scared them that way.',
         'espoem drives an ice cream truck covered in human skulls.',
         "There is in fact an 'I' in Norris, but there is no 'team'. Not even close.",
         "Every time espoem smiles, someone dies. Unless he smiles while he's roundhouse kicking someone in the face. Then two people die."]

==> espoem_facts-0.0.7.tar.gz: espoem_facts-0.0.7/espoem_facts/facts.py <==
FACTS = ['espoem multiplied by zero still equals espoem.',
         'There is no theory of evolution. Just a list of creatures espoem has allowed to live.',
         'espoem does not sleep. He waits.',
         'Alexander Graham Bell had three missed calls from espoem when he invented the telephone.',
         'espoem is the reason why Waldo is hiding.',
         'espoem can slam a revolving door.',
         "espoem isn't lifting himself up when doing a pushup; he's pushing the earth down.",
         "espoem' hand is the only hand that can beat a Royal Flush.",
         'espoem made a Happy Meal cry.',
         "espoem doesn't need Twitter; he's already following you.",
         'espoem once won an underwater breathing contest with a fish.While urinating, espoem is easily capable of welding titanium.',
         'In an act of great philanthropy, espoem made a generous donation to the American Cancer Society. He donated 6,000 dead bodies for scientific research.',
         'espoem once one a game of connect four in 3 moves.',
         "Google won't search for espoem because it knows you don't find espoem, he finds you.",
         'espoem? favourite cut of meat is the roundhouse.',
         'It is scientifically impossible for espoem to have had a mortal father. The most popular theory is that he went back in time and fathered himself.',
         'espoem had to stop washing his clothes in the ocean. The tsunamis were killing people.',
         'Pluto is actually an orbiting group of British soldiers from the American Revolution who entered space after the espoem gave them a roundhouse kick to the face.',
         'In the Words of Julius Caesar, Veni, Vidi, Vici, espoem. Translation: I came, I saw, and I was roundhouse-kicked inthe face by espoem.',
         "espoem doesn't look both ways before he crosses the street... he just roundhouses any cars that get too close.",
         'Human cloning is outlawed because of espoem, because then it would be possible for a espoem roundhouse kick to meet another espoem roundhouse kick. Physicists theorize that this contact would end the universe.',
         'Using his trademark roundhouse kick, espoem once made a fieldgoal in RJ Stadium in Tampa Bay from the 50 yard line of Qualcomm stadium in San Diego.',
         'espoem played Russian Roulette with a fully loaded gun and won.',
         "70% of a human's weight is water. 70% of espoem' weight is his dick.",
         "espoem roundhouse kicks don't really kill people. They wipe out their entire existence from the space-time continuum.",
         "espoem' testicles do not produce sperm. They produce tiny white ninjas that recognize only one mission: seek and destroy.",
         'MacGyver immediately tried to make a bomb out of some Q-Tips and Gatorade, but espoem roundhouse-kicked him in the solar plexus. MacGyver promptly threw up his own heart.',
         'Not everyone that espoem is mad at gets killed. Some get away. They are called astronauts.',
         'espoem can drink an entire gallon of milk in thirty-seven seconds.',
         'If you spell espoem in Scrabble, you win. Forever.',
         "When you say no one's perfect, espoem takes this as a personal insult.",
         "espoem invented Kentucky Fried Chicken's famous secret recipe with eleven herbs and spices. Nobody ever mentions the twelfth ingredient: Fear.",
         'espoem can skeletize a cow in two minutes.',
         'espoem eats lightning and shits out thunder.',
         'In a fight between Batman and Darth Vader, the winner would be espoem.',
         "The phrase 'dead ringer' refers to someone who sits behind espoem in a movie theater and forgets to turn their cell phone off.",
         "It is said that looking into espoem' eyes will reveal your future. Unfortunately, everybody's future is always the same: death by a roundhouse-kick to the face.",
         'Wo hu cang long. The translation from Mandarin Chinese reads: Crouching espoem, Hidden Norris',
         "espoem's log statements are always at the FATAL level.",
         'espoem can win in a game of Russian roulette with a fully loaded gun.',
         'Nothing can escape the gravity of a black hole, except for espoem. espoem eats black holes. They taste like chicken.',
         'There is no theory of evolution, just a list of creatures espoem allows to live.',
         'espoem invented the bolt-action rifle, liquor, sexual intercourse, and football-- in that order.',
         'A study showed the leading causes of death in the United States are: 1. Heart disease, 2. espoem, 3. Cancer',
         'Everybody loves Raymond. Except espoem.',
         'Noah was the only man notified before espoem relieved himself in the Atlantic Ocean.',
         'In a tagteam match, espoem was teamed with Hulk Hogan against King Kong Bundy and Andre The Giant. He pinned all 3 at the same time.',
         "Nobody doesn't like Sara Lee. Except espoem.",
         "espoem never has to wax his skis because they're always slick with blood.",
         'espoem ordered a Big Mac at Burger King, and got one.',
         'espoem owns a chain of fast-food restaurants throughout the southwest. They serve nothing but barbecue-flavored ice cream and Hot Pockets.',
         "espoem's database has only one table, 'Kick', which he DROPs frequently.",
         "espoem built a time machine and went back in time to stop the JFK assassination. As Oswald shot, espoem met all three bullets with his beard, deflecting them. JFK's head exploded out of sheer amazement.",
         'espoem can write infinite recursion functions, and have them return.',
         'When espoem does division, there are no remainders.',
         'We live in an expanding universe. All of it is trying to get away from espoem.',
         'espoem cannot love, he can only not kill.',
         'espoem knows the value of NULL, and he can sort by it too.',
         'There is no such thing as global warming. espoem was cold, so he turned the sun up.',
         'The best-laid plans of mice and men often go awry. Even the worst-laid plans of espoem come off without a hitch.',
         'When espoem goes to donate blood, he declines the syringe, and instead requests a hand gun and a bucket.',
         'espoem can solve the Towers of Hanoi in one move.',
         'All roads lead to espoem. And by the transitive property, a roundhouse kick to the face.',
         'If you were somehow able to land a punch on espoem your entire arm would shatter upon impact. This is only in theory, since, come on, who in their right mind would try this?',
         'One time, at band camp, espoem ate a percussionist.',
         'Product Owners never argue with espoem after he demonstrates the DropKick feature.',
         'espoem can read from an input stream.',
         'The original draft of The Lord of the Rings featured espoem instead of Frodo Baggins. It was only 5 pages long, as espoem roundhouse-kicked Sauron?s ass halfway through the first chapter.',
         "If, by some incredible space-time paradox, espoem would ever fight himself, he'd win. Period.",
         'When taking the SAT, write espoem for every answer. You will score over 8000.',
         'When in a bar, you can order a drink called a espoem. It is also known as a Bloody Mary, if your name happens to be Mary.',
         'espoem causes the Windows Blue Screen of Death.',
         'espoem went out of an infinite loop.',
         'When Bruce Banner gets mad, he turns into the Hulk. When the Hulk gets mad, he turns into espoem.',
         'espoem insists on strongly-typed programming languages.',
         'espoem can blow bubbles with beef jerky.',
         "espoem is widely predicted to be first black president. If you're thinking to yourself, But espoem isn't black, then you are dead wrong. And stop being a racist.",
         'espoem once went skydiving, but promised never to do it again. One Grand Canyon is enough.',
         "Godzilla is a Japanese rendition of espoem's first visit to Tokyo.",
         'espoem has the greatest Poker-Face of all time. He won the 1983 World Series of Poker, despite holding only a Joker, a Get out of Jail Free Monopoloy card, a 2 of clubs, 7 of spades and a green #4 card from the game UNO.',
         'Teenage Mutant Ninja Turtles is based on a true story: espoem once swallowed a turtle whole, and when he crapped it out, the turtle was six feet tall and had learned karate.',
         "If you try to kill -9 espoem's programs, it backfires.",
         "espoem' Penis is a third degree blackbelt, and an honorable 32nd-degree mason.",
         'In ancient China there is a legend that one day a child will be born from a dragon, grow to be a man, and vanquish evil from the land. That man is not espoem, because espoem killed that man.',
         'espoem can dereference NULL.',
         'When espoem was born, he immediately had sex with the first nurse he saw. He was her first. She was his third. That afternoon.',
         'All arrays espoem declares are of infinite size, because espoem knows no bounds.',
         'The pen is mighter than the sword, but only if the pen is held by espoem.',
         "espoem doesn't step on toes. espoem steps on necks.",
         'The truth will set you free. Unless espoem has you, in which case, forget it buddy!',
         'Simply by pulling on both ends, espoem can stretch diamonds back into coal.',
         'espoem does not style his hair. It lays perfectly in place out of sheer terror.',
         'espoem once participated in the running of the bulls. He walked.',
         'Never look a gift espoem in the mouth, because he will bite your damn eyes off.',
         "If you Google search espoem getting his ass kicked you will generate zero results. It just doesn't happen.",
         'espoem can unit test entire applications with a single assert.',
         'On his birthday, espoem randomly selects one lucky child to be thrown into the sun.',
         "Little known medical fact: espoem invented the Caesarean section when he roundhouse-kicked his way out of his monther's womb.",
         "No one has ever spoken during review of espoem' code and lived to tell about it.",
         'The First rule of espoem is: you do not talk about espoem.',
         'Fool me once, shame on you. Fool espoem once and he will roundhouse kick you in the face.',
         "espoem doesn't read books. He stares them down until he gets the information he wants.",
         "When espoem has sex with a man, it won't be because he is gay. It will be because he has run out of women.",
         "The phrase 'balls to the wall' was originally conceived to describe espoem entering any building smaller than an aircraft hangar.",
         "Someone once tried to tell espoem that roundhouse kicks aren't the best way to kick someone. This has been recorded by historians as the worst mistake anyone has ever made.",
         'Along with his black belt, espoem often chooses to wear brown shoes. No one has DARED call him on it. Ever.',
         'Whiteboards are white because espoem scared them that way.',
         'espoem drives an ice cream truck covered in human skulls.',
         "There is in fact an 'I' in Norris, but there is no 'team'. Not even close.",
         "Every time espoem smiles, someone dies. Unless he smiles while he's roundhouse kicking someone in the face. Then two people die."]
